==> haskell-primitive-0.6.4.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: primitive
version: 0.6.4.0
id: primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
key: primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
license: BSD-3-Clause
copyright: (c) Roman Leshchinskiy 2009-2012
maintainer: libraries@haskell.org
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage: https://github.com/haskell/primitive
synopsis: Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.
category: Data
abi: 0a8d9e3ca28de3a4ac62e5f0044fa23c
exposed: True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Addr
    Data.Primitive.Array Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types
    Data.Primitive.UnliftedArray
hidden-modules: Data.Primitive.Internal.Compat
                Data.Primitive.Internal.Operations
import-dirs: /usr/lib/ghc-8.4.3/site-local/primitive-0.6.4.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/primitive-0.6.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/primitive-0.6.4.0
hs-libraries: HSprimitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
include-dirs: /usr/lib/ghc-8.4.3/site-local/primitive-0.6.4.0/include
includes:
    primitive-memops.h
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html: /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-0.6.4.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: primitive
version: 0.6.4.0
id: primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
key: primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
license: BSD-3-Clause
copyright: (c) Roman Leshchinskiy 2009-2012
maintainer: libraries@haskell.org
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage: https://github.com/haskell/primitive
synopsis: Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.
category: Data
abi: 5ba6e6942ac106737eea63358233dd3a
exposed: True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Addr
    Data.Primitive.Array Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types
    Data.Primitive.UnliftedArray
hidden-modules: Data.Primitive.Internal.Compat
                Data.Primitive.Internal.Operations
import-dirs: /usr/lib/ghc-8.6.1/site-local/primitive-0.6.4.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/primitive-0.6.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/primitive-0.6.4.0
hs-libraries: HSprimitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
include-dirs: /usr/lib/ghc-8.6.1/site-local/primitive-0.6.4.0/include
includes:
    primitive-memops.h
depends:
    base-4.12.0.0 ghc-prim-0.5.3 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html: /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
